@@ -62,7 +62,7 @@ cb_dialog_response (GtkDialog *dialog, gint response_id)
 {
 	if (response_id == GTK_RESPONSE_HELP)
 		capplet_help (GTK_WINDOW (dialog),
-			"wgoscustdesk.xml",
+			"user-guide.xml",
 			"goscustdesk-38");
 	else
 		gtk_main_quit ();
@@ -86,7 +86,7 @@ sample_size_request (GtkWidget      *darea,
 
 static void
 sample_expose (GtkWidget      *darea,
-	       GdkEventExpose  expose)
+	       GdkEventExpose *expose)
 {
 	GdkPixbuf *pixbuf = g_object_get_data (G_OBJECT (darea), "sample-pixbuf");
 	int width = gdk_pixbuf_get_width (pixbuf);
@@ -504,12 +504,16 @@ application_font_to_gconf (GConfPropertyEditor *peditor,
 		if (danger_level > MAX_FONT_POINT_WITHOUT_WARNING) {
 			warning_label = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
 							 _("Font may be too large"),
-							 _("The font selected is %d points large, and may make it difficult to effectively use the computer.  It is recommended that you select a size smaller than %d."));
+							 ngettext ("The font selected is %d point large, and may make it difficult to effectively use the computer.  It is recommended that you select a size smaller than %d.",
+								   "The font selected is %d points large, and may make it difficult to effectively use the computer.  It is recommended that you select a size smaller than %d.",
+								   danger_level));
 			warning_label2 = g_strdup_printf (warning_label, danger_level, MAX_FONT_POINT_WITHOUT_WARNING);
 		} else {
 			warning_label = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
 							 _("Font may be too large"),
-							 _("The font selected is %d points large, and may make it difficult to effectively use the computer.  It is recommended that you select a smaller sized font."));
+							 ngettext ("The font selected is %d point large, and may make it difficult to effectively use the computer.  It is recommended that you select a smaller sized font.",
+								   "The font selected is %d points large, and may make it difficult to effectively use the computer.  It is recommended that you select a smaller sized font.",
+								   danger_level));
 			warning_label2 = g_strdup_printf (warning_label, danger_level);
 		}
 		gtk_label_set_markup (GTK_LABEL (WID ("font_size_warning_label")), warning_label2);
@@ -787,7 +791,7 @@ cb_details_response (GtkDialog *dialog, gint response_id)
 {
 	if (response_id == GTK_RESPONSE_HELP)
 		capplet_help (GTK_WINDOW (dialog),
-			      "wgoscustdesk.xml",
+			      "user-guide.xml",
 			      "goscustdesk-38");
 	else if (response_id == 1) {
 		/* "Go to font folder" was clicked */
